@@ -26,9 +26,9 @@ use Encode qw(encode);
 use YAML qw(Dump);
 use JSON qw();
 
-__PACKAGE__->mk_accessors(qw(to_xml to_hash to_yaml to_json));
+__PACKAGE__->mk_accessors(qw(to_xml to_hash to_yaml to_json from_xml));
 
-our $VERSION = '0.1';
+our $VERSION = '0.4';
 
 # Default values
 my $PATH = '/files';
@@ -179,7 +179,10 @@ W: You will not be able to import it back.\n";
 
 
 sub node_to_xml {
-   my ($self, $path, $excludes) = @_;
+   my ($self, $path, $excludes, $check_is_file) = @_;
+
+   # Default check is_file
+   $check_is_file = 1 unless(defined($check_is_file));
 
    # Get label from path
    my $label = get_label($path);
@@ -193,19 +196,25 @@ sub node_to_xml {
    my $aug = $self->{aug};
    my @children = $aug->match("$path/*");
 
+   # Should children check is_file?
+   my $children_check_is_file = $check_is_file;
+   if ($check_is_file && is_file($self, $path)) {
+      $children_check_is_file = 0;
+   }
+
    # Parse children
    my @child_elems;
    for my $child (@children) {
-      my @new_child_elems = (node_to_xml($self, $child, $excludes));
+      my @new_child_elems = (node_to_xml($self, $child, $excludes, $children_check_is_file));
       map { push @child_elems, $_ } @new_child_elems;
    }
 
    # Directories don't get their own node
-   return @child_elems if ($self->is_dir($path));
+   return @child_elems if ($check_is_file && $self->is_dir($path));
 
    # Files and entries get their own nodes
    my $elem;
-   if (is_file($self, $path)) {
+   if ($check_is_file && is_file($self, $path)) {
       # Files get <file path="$path"> nodes
       $elem = XML::LibXML::Element->new('file');
       my $file_path = get_file_path($path);
@@ -399,6 +408,11 @@ sub from_xml {
 
    my @files = $xml->find('/augeas/files/file')->get_nodelist();
 
+   if ($#files < 0) {
+      warn "W: The XML document contains no file to restore.";
+      return;
+   }
+
    for my $file (@files) {
       my $path = $file->getAttribute('path');
       my $aug_path = "/files${path}";
@@ -563,7 +577,7 @@ http://augeas.net/ : The Augeas project page
 
 =head1 AUTHOR
 
-RaphaE<euml>l Pinson, E<lt>raphink at gmail dot comE<gt>
+RaphaE<euml>l Pinson, E<lt>raphink at cpan dot orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
